<?php

/**
 * The header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package Histogram Pro
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
    <?php wp_body_open(); ?>

    <div class="page-loading">
        <div class="loader">
            <svg version="1.1" id="L5" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 100 100" enable-background="new 0 0 0 0" xml:space="preserve">
                <circle fill="#fff" stroke="none" cx="6" cy="50" r="6">
                    <animateTransform attributeName="transform" dur="1s" type="translate" values="0 15 ; 0 -15; 0 15" repeatCount="indefinite" begin="0.1" />
                </circle>
                <circle fill="#fff" stroke="none" cx="30" cy="50" r="6">
                    <animateTransform attributeName="transform" dur="1s" type="translate" values="0 10 ; 0 -10; 0 10" repeatCount="indefinite" begin="0.2" />
                </circle>
                <circle fill="#fff" stroke="none" cx="54" cy="50" r="6">
                    <animateTransform attributeName="transform" dur="1s" type="translate" values="0 5 ; 0 -5; 0 5" repeatCount="indefinite" begin="0.3" />
                </circle>
            </svg>
        </div>
    </div>

    <div id="page" class="hfeed site">
        <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e('Skip to content', 'histogram-pro'); ?></a>

        <header id="masthead" class="site-header" role="banner">
            <?php

            // Logo
            $logo_id = get_theme_mod('custom_logo');
            $logo_url = wp_get_attachment_image_src($logo_id, 'full');

            // Retina logo
            $retina_id  = get_theme_mod('retina_logo');
            $retina_url = wp_get_attachment_image_src($retina_id, 'full');
            if ($logo_id) {
            ?>
                <a class="site-logo" href="<?php echo esc_url(home_url()); ?>" rel="home">
                    <?php if ($retina_id) { ?>
                        <img srcset="<?php echo esc_url($retina_url[0]); ?> 2x" src="<?php echo esc_url($logo_url[0]); ?>" alt="<?php echo esc_attr(get_bloginfo('name')); ?>" />
                    <?php } else { ?>
                        <img src="<?php echo esc_url($logo_url[0]); ?>" alt="<?php echo esc_attr(get_bloginfo('name')); ?>" />
                    <?php } ?>
                </a>
            <?php } ?>

            <div class="site-branding">
                <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>" rel="home"><?php bloginfo('name'); ?></a></h1>
            </div><!-- .site-branding -->
            <p class="site-description"><?php bloginfo('description'); ?></p>

            <nav id="site-navigation" class="main-navigation" role="navigation">
                <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e('Menu', 'histogram-pro'); ?></button>
                <?php wp_nav_menu(array('theme_location' => 'primary', 'menu_id' => 'primary-menu')); ?>
            </nav><!-- #site-navigation -->

            <?php
            if (has_nav_menu('social')) :
                wp_nav_menu(array(
                    'theme_location'  => 'social',
                    'container_class' => 'social-links',
                    'depth'           => 1,
                    'link_before'     => '<span class="screen-reader-text">',
                    'link_after'      => '</span>',
                ));
            endif;
            ?>

            <?php if (is_active_sidebar('sidebar-3')) : ?>
                <div id="widget-area-3" class="widget-area">
                    <?php dynamic_sidebar('sidebar-3'); ?>
                </div><!-- #widget-area-1 -->
            <?php endif; ?>

        </header><!-- #masthead -->

        <div id="content" class="site-content">
