<?php

/**
 * Histogram Pro Theme Customizer
 *
 * @package Histogram Pro
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function histogram_customize_register($wp_customize) {
    $wp_customize->get_setting('blogname')->transport         = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport  = 'postMessage';

    // Enable selective refresh to the Site Title
    if (isset($wp_customize->selective_refresh)) {
        $wp_customize->selective_refresh->add_partial('blogname', array(
            'selector'         => '.site-title a',
            'settings'         => array('blogname'),
            'render_callback'  => function () {
                return get_bloginfo('name', 'display');
            }
        ));
    }

    // Enable selective refresh to the Site Description
    if (isset($wp_customize->selective_refresh)) {
        $wp_customize->selective_refresh->add_partial('blogdescription', array(
            'selector'         => '.site-description',
            'settings'         => array('blogdescription'),
            'render_callback'  => function () {
                return get_bloginfo('description', 'display');
            }
        ));
    }

    // Remove section
    $wp_customize->remove_section('colors');
    $wp_customize->remove_section('background_image');
}
add_action('customize_register', 'histogram_customize_register');

/**
 * Add the configuration.
 * This way all the fields using the 'histogram_options' ID
 * will inherit these options
 */
Kirki::add_config('histogram_options', array(
    'capability'    => 'edit_theme_options',
    'option_type'   => 'theme_mod',
));

/**
 * Disable Kirki loader
 */
add_filter('kirki/config', function ($config) {
    $config['disable_loader'] = true;
    return $config;
});

/**
 * Add sections
 */
/**
 * Header panel
 */
Kirki::add_panel('theme_settings', array(
    'title'       => esc_attr__('Theme Settings', 'histogram-pro'),
    'description' => esc_attr__('Customize the theme.', 'histogram-pro'),
    'priority'    => 140,
));

require get_template_directory() . '/inc/options/logo-retina.php';
require get_template_directory() . '/inc/options/style.php';
require get_template_directory() . '/inc/options/background.php';
require get_template_directory() . '/inc/options/typography.php';
require get_template_directory() . '/inc/options/home.php';
require get_template_directory() . '/inc/options/sidebar.php';
