<?php

/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Histogram Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function histogram_body_classes($classes) {
    // Adds a class of group-blog to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }

    // Adds a class when Jetpack's "Hide website title" option is checked.
    if (get_theme_mod('custom_logo')) {
        $classes[] = 'hide-site-title';
    }

    return $classes;
}
add_filter('body_class', 'histogram_body_classes');

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function histogram_post_classes($classes) {

    if ('portfolio' == get_post_type()) {
        $classes[] = 'portfolio-entry';

        if (!has_post_thumbnail()) {
            $classes[] = 'no-thumbnail';
        }
    }

    return $classes;
}
add_filter('post_class', 'histogram_post_classes');

/**
 * Display page-links for paginated posts before Jetpack share buttons and related posts.
 */
function histogram_custom_link_pages($content) {
    if (is_singular() && is_main_query()) {
        $content .= wp_link_pages(array(
            'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__('Pages:', 'histogram-pro') . '</span>',
            'after'       => '</div>',
            'link_before' => '<span>',
            'link_after'  => '</span>',
            'echo'          => 0,
        ));
    }
    return $content;
}
add_filter('the_content', 'histogram_custom_link_pages', 1);
