<?php

/**
 * Template Name: Portfolio Page Template
 *
 * @package Histogram Pro
 */

get_header(); ?>

<div id="primary" class="content-area">
    <main id="main" class="site-main" role="main">

        <?php
        $title   = get_theme_mod('welcome_title');
        $content = get_theme_mod('welcome_content');
        if ($title || $content) {
        ?>
            <header class="page-header">
                <h2 class="welcome-title"><?php echo esc_html($title); ?></h2>
                <div class="welcome-content"><?php echo wp_kses_post($content); ?></div>
            </header><!-- .page-header -->
        <?php } ?>

        <?php if (post_password_required()) :
            the_content();

        else :

            if (get_query_var('paged')) :
                $paged = get_query_var('paged');
            elseif (get_query_var('page')) :
                $paged = get_query_var('page');
            else :
                $paged = 1;
            endif;

            $number = get_theme_mod('portfolio_number', 10);
            $args = array(
                'post_type'      => 'portfolio',
                'posts_per_page' => absint($number),
                'paged'          => $paged,
            );
            $project_query = new WP_Query($args);
            if (post_type_exists('portfolio') && $project_query->have_posts()) :
        ?>

                <div class="portfolio-wrapper">

                    <?php /* Start the Loop */ ?>
                    <?php while ($project_query->have_posts()) : $project_query->the_post(); ?>

                        <?php get_template_part('template-parts/content', 'portfolio'); ?>

                    <?php endwhile; ?>

                </div><!-- .portfolio-wrapper -->

                <?php
                histogram_paging_nav($project_query->max_num_pages);
                wp_reset_postdata();
                ?>

            <?php else : ?>

                <section class="no-results not-found">
                    <header class="page-header">
                        <h1 class="page-title"><?php esc_html_e('Nothing Found', 'histogram-pro'); ?></h1>
                    </header><!-- .page-header -->

                    <div class="page-content">
                        <?php if (current_user_can('publish_posts')) : ?>

                            <p><?php printf(wp_kses(__('Ready to publish your first post? <a href="%1$s">Get started here</a>.', 'histogram-pro'), array('a' => array('href' => array()))), esc_url(admin_url('post-new.php'))); ?></p>

                        <?php else : ?>

                            <p><?php esc_html_e('It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'histogram-pro'); ?></p>
                            <?php get_search_form(); ?>

                        <?php endif; ?>
                    </div><!-- .page-content -->
                </section><!-- .no-results -->

            <?php endif; ?>

        <?php endif; // end post_password_required()
        ?>

    </main><!-- #main -->
</div><!-- #primary -->

<?php get_footer(); ?>
